Bootstrap_example: Output example for a bootstrapping analysis conducted with...

Bootstrap_exampleR Documentation

Output example for a bootstrapping analysis conducted with the ResIN package

Description

Output example for a bootstrapping analysis conducted with the ResIN package

Usage

data(Bootstrap_example)

Format

An object of class "rda"

References

This dataset was made available by Lüders et.al. 2024.

Examples


data(Bootstrap_example)
names(Bootstrap_example[[1]])


ResIN documentation built on March 2, 2026, 9:07 a.m.