View source: R/ResIN_boots_extract.R
| ResIN_boots_extract | R Documentation |
Extract bootstrap draws from "ResIN_boots_executed" results. Failed iterations
(stored as NULL) are skipped automatically.
ResIN_boots_extract(
ResIN_boots_executed,
what,
summarize_results = FALSE,
allow_missing = FALSE
)
ResIN_boots_executed |
An object of class |
what |
Character scalar naming the quantity to extract (e.g., |
summarize_results |
Logical; if TRUE return a small summary table, otherwise return draws. |
allow_missing |
Logical; if FALSE (default) the function errors if |
If the extracted quantity is scalar per iteration, returns an object of class
"ResIN_boots_draws" (a numeric vector with attributes). If summarize_results = TRUE,
returns a one-row data.frame of summary statistics.
## Load the 12-item simulated Likert-type toy dataset
data(lik_data)
# Apply the ResIN function to toy Likert data:
ResIN_obj <- ResIN(lik_data, network_stats = TRUE,
generate_ggplot = FALSE, plot_ggplot = FALSE)
# Prepare for bootstrapping
prepped_boots <- ResIN_boots_prepare(ResIN_obj, n=100, boots_type="resample")
# Execute the prepared bootstrap list
executed_boots <- ResIN_boots_execute(prepped_boots, parallel = TRUE, detect_cores = TRUE)
# Extract results - here for example, the network (global)-clustering coefficient
ResIN_boots_extract(executed_boots, what = "global_clustering", summarize_results = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.