View source: R/ResIN_boots_prepare.R
| ResIN_boots_prepare | R Documentation |
Provides instructions for how to bootstrap a ResIN network to derive uncertainty estimates around core quantities of interest. Requires output of ResIN function.
ResIN_boots_prepare(
ResIN_object,
n = 10000,
boots_type = "resample",
resample_size = NULL,
weights = NULL,
save_input = FALSE,
seed_boots = 42
)
ResIN_object |
A ResIN object to prepare bootstrapping workflow. |
n |
Bootstrapping sample size. Defaults to 10.000. |
boots_type |
What kind of bootstrapping should be performed? If set to "resample", function performs row-wise re-sampling of raw data (useful for e.g., sensitivity or power analysis). If set to "permute", function will randomly reshuffle raw item responses (useful e.g., for simulating null-hypothesis distributions). Defaults to "resample". |
resample_size |
Optional parameter determining sample size when |
weights |
An optional weights vector that can be used to adjust the re-sampling of observations. Should either be NULL (default) or a positive numeric vector of the same length as the original data. |
save_input |
Should all input information for each bootstrap iteration (including re-sampled/permuted data) be stored. Set to FALSE by default to save a lot of memory and disk storage. |
seed_boots |
Random seed for bootstrap samples |
An object of class "ResIN_boots_prepped" containing a bootstrap plan
(specification) used by ResIN_boots_execute.
Use print(), summary(), length(), and [
to inspect or subset the plan. See ResIN_boots_prepped for details.
## Load the 12-item simulated Likert-type toy dataset
data(lik_data)
# Apply the ResIN function to toy Likert data:
ResIN_obj <- ResIN(lik_data, network_stats = TRUE,
generate_ggplot = FALSE, plot_ggplot = FALSE)
# Prepare for bootstrapping
prepped_boots <- ResIN_boots_prepare(ResIN_obj, n=100, boots_type="resample")
# Execute the prepared bootstrap list
executed_boots <- ResIN_boots_execute(prepped_boots, parallel = TRUE, detect_cores = TRUE)
# Extract results - here for example, the network (global)-clustering coefficient
ResIN_boots_extract(executed_boots, what = "global_clustering", summarize_results = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.